/* BUFFERED.C Copyright 2005 WinSystems Inc. All rights reserved
**************************************************************************
*
*   Name    : buffered.c
*
*   Project : EPX-GX Analog
*
*   Purpose : User sample code
*
*   Revision: 1.00
*
*   Date    : September 8, 2005
*
*   Author  : Steve Mottin
*
**************************************************************************
*
*   Revision History
*
*   Date        Revision    Desciption
*   --------    --------    ----------------------------------------------
*   09/08/05    1.00        Created
*
**************************************************************************
*/

/* This program demonstrates a special feature of the support library which
   alloww for a programmed sequence of conversions to be accomplished at
   speed, and the results are placed in a buffer for later processing.

   The input buffer is simply a list of channels to be converted in the
   desired order. The list is terminated with a hex FF value.  The list
   is stored in a character array and the results are stored in an unsigned
   integer array. 

   This program will load the array such that 500 samples each will be
   made on channels 0-3 in succession.

   This program was built and tested using the Borland C/C++ Comppiler
   Version 3.1. It may be rebuilt using the accompanying Makefile or may
   be built at the DOS command line with :

        bcc buffered.c gxa2d.c
*/


#include <stdio.h>
#include <stdlib.h>
#include <conio.h>
#include "gxa2d.h"

    /* The to_do array will hold the list of channels to be converted. Note
       that its length is one longer than the total number of conversions
       requested to allow for the terminating 0xff character.
    */

unsigned char to_do_channels[2001];

    /* The results will be placed inthe values array. It's up to the user
       to know what data belongs to what channel(s)
    */

unsigned values[2000];


void main(void)
{
int channel = 0;
unsigned result;
float min,max,current;
unsigned long count;
int x;
int c;

        /* First we'll set the mode on all 8 channels to a single-ended,
          bipolar, +/-10V scale. This alllows any legal input to be placed
          on any input.
        */

       for(channel=0; channel < 8; channel++ )
	   {
		   gxad_set_channel_mode(channel,GXAD_SINGLE_ENDED,GXAD_BIPOLAR,GXAD_TOP_10V);
		   if(gxad_error_code)
		   {
			   printf("Error occured on Channel %d - %s\n",channel,gxad_error_string);
			   exit(1);
		   }
	   }
        /* We'll fill the to_do list with the four different channels 500
           eachg successively.
        */

       for(x=0; x<500; x++)
       {
            to_do_channels[x] = 0;
            to_do_channels[x+500] = 1;
            to_do_channels[x+1000] = 2;
            to_do_channels[x+1500] = 3;
       }

       /* Load the terminator into the last location */

       to_do_channels[2000] = 0xff;

       /* We'll keep going until a key is pressed */

       while(!kbhit())
       {
            /* Start up the conversions. This function returns when
               all 2000 of our conversions are complete.
            */

            gxad_buffered_channel_conversions(to_do_channels,values);
			if(gxad_error_code)
			{
				printf("Error occured - %s\n",gxad_error_string);
				exit(1);
			}


            /* We'll now extract our data from the "values" array. In
            order to make the display more readable. We'll take a value
            from each channel display them, and then move to the next
            result.
            */

            for(x=0; x<500; x++)
            {
                /* Get the raw data */

                result = values[x];
                
                /* Adjust for bipolar modes */

                result = result + gxad_adjust[0];

                /* Convert to voltage */

                current = result * gxad_bitval[0];

                /* One more adjustment for bipolar modes */

                current = current + gxad_offset[0];

                /* Display the value */

                printf("CH0 %9.5f  ",current);

                /* Repeat for channels 1-3 */

                result = values[x+500];
                result = result + gxad_adjust[1];
                current = result * gxad_bitval[1];
                current = current + gxad_offset[1];
                printf("CH1 %9.5f  ",current);

                result = values[x+1000];
                result = result + gxad_adjust[2];
                current = result * gxad_bitval[2];
                current = current + gxad_offset[2];
                printf("CH2 %9.5f  ",current);

                result = values[x+1500];
                result = result + gxad_adjust[3];
                current = result * gxad_bitval[3];
                current = current + gxad_offset[3];
                printf("CH3 %9.5f  ",current);
                printf("\r");
            }
    }
    getch();
}



