/* GETALL.C Copyright 2005 Winsystems Inc. All Rights Reserved
**************************************************************************
*
*   Name    : getall.c
*
*   Project : EPX-GX Analog
*
*   Purpose : User sample code
*
*   Revision: 1.00
*
*   Date    : September 8, 2005
*
*   Author  : Steve Mottin
*
**************************************************************************
*
*   Revision History
*
*   Date        Revision    Description
*   --------    --------    ----------------------------------------------
*   09/08/05    1.00        Created
*
**************************************************************************
*/

/* This program demonstrates usage of the gxad_convert_all_channels
   function call. This allows for all 8 channels to be quickly converted
   and the results passed back in an 8 element array. Note that this
   function does not return voltage values, it returns raw 16-bti data
   directly from the converter.
*/

#include <stdio.h>
#include <stdlib.h>
#include <conio.h>

#include "gxa2d.h"

/* This array will receive the 8 result values for all 8 channels */

unsigned values[16];


void main(void)
{
int channel = 0;
unsigned result;
float current;


    /* We set the mode on all 8 channels to single-ended bipolar +/-10V
       scale. This allows any legal voltage to be applied to any channel.
    */

       for(channel=0; channel < 8; channel++)
	   {
		   gxad_set_channel_mode(channel,GXAD_SINGLE_ENDED,GXAD_BIPOLAR,GXAD_TOP_10V);
		   if(gxad_error_code)
		   {
			   printf("Error occured on channel %d - %s\n",channel,gxad_error_string);
			   exit(1);
		   }
	   }

     /* We'll run until a key is pressed */

       while(!kbhit())
       {
            /* This is it. The result is 8 channels of data stored
               in the "values" array.
            */

            gxad_convert_all_channels(values);
		    if(gxad_error_code)
			{
					printf("Error Occured - %s\n",gxad_error_string);
					exit(1);
			}

            /* Now we'll actually look at the data, convert it to volts
               and display the results.
            */

            for(channel =0; channel <8; channel++)
            {

                /* Channel by channel retrieve the raw conversion data */

                result = values[channel];

                /* Adjust for bipolar linearity */

                result = result + gxad_adjust[channel];

                /* Multiply by our bit voltage value to convert to volts */

                current = result * gxad_bitval[channel];

                /* Final adjustment for biplor +/- scales */

                current = current + gxad_offset[channel];

                /* Display each channels voltage. Not that we purposely
                   cut down the number of digits displayed so that alll
                   8 channels could be displayed on a single line.
                */

                printf("CH%1d%5.2f ",channel,current);
             }
             printf("\r");
       }
       getch();
}



