/* GETVOLT.C Copyright 2005 WinSystems Inc. All Rights Reserved
**************************************************************************
*
*   Name    : getvolt.c
*
*   Project : EPX-GX Analog input
*
*   Purpose : Sample code
*
*   Revision: 1.00
*
*   Date    : September 8,2005
*
*   Author  : Steve Mottin
*
**************************************************************************
*
*   Revision History
*
*   Date        Revision    Description
*   --------    --------    ----------------------------------------------
*   09/08/05    1.00        Created
*
**************************************************************************
*/

/* This program demonstrates the absolutely simplest way to use
   the LTC185X A/D converter on the EPX-GX board. It uses the full
   auto-ranging feature of the support functions to return the current
   voltage on an input pin. This function only works in single ended mode.

    This program was developed and tested using the Borlandc C/C++ compiler
    version 3.1. It can be rebuilt with the supplied Makefile or at a
    DOS command line with.

        bcc getvolt.c gxa2d.c

*/

#include <stdio.h>
#include <stdlib.h>
#include "gxa2d.h"

void main(int argc, char *argv[])
{
float value;
int channel = 0;

       /* Default to channel 0, but allow a command line argument */

       if(argc > 1)
            channel = atoi(argv[1]);

       /* Check channel number for validity */

       if(channel < 0 || channel > 7)
       {
            printf("Channel numbers must be between 0 and 7 - Aborting\n");
            exit(0);
       }

        /* Here's the whole thing make the call, get back a voltage */

       value = gxad_auto_get_channel_voltage(channel);

		/* Check for an error, just in case */

	   if(gxad_error_code)
	   {
		   printf("Error occured - %s\n",gxad_error_string);
		   exit(1);
	   }

        /* Print it out */

       printf("Channel %d = %9.5f\n",channel,value);
}



