/* REPEAT.C Copyright 2005 WinSystems Inc. All rights reserved.
**************************************************************************
*
*   Name    : repeat.c
*
*   Project : EPX-GX Support
*
*   Purpose : Sample user code
*
*   Revision: 1.00
*
*   Date    : September 8, 2005
*
*   Author  : Steve Mottin
*
**************************************************************************
*
*   Revision History
*
*   Date        Revision    Description
*   --------    --------    ----------------------------------------------
*   09/08/05    1.00        Created
*
**************************************************************************
*/

/* This program demonstrates the gxad_convert_single_repeated function
   call in the support library. This function allows for a specified
   number of conversions to be completed and the results placed in a
   buffer before returning. Not this function returns raw 16-bit values
   and it does not return any voltage values.
*/

#include <stdio.h>
#include <stdlib.h>
#include <conio.h>

#include "gxa2d.h"

/* This array will store the results of the 2000 conversions */

unsigned values[2000];

void main(int argc, char *argv[])
{
int channel = 0;
unsigned result;
float min,max,current;
unsigned long count;
int x;
int c;

       /* We'll keep track of the minimum and maximum voltage values
          we see on a channel as well as the count of conversions
          completed.
       */

       max = -10.0;
       min = 10.0;
       count = 0;

       /* The default channel is channel 0 but an alternate channel can
          be specified as a commmand line argument.
       */

       if(argc > 1)
            channel = atoi(argv[1]);

       /* Check for a valid channel number - Abort if bad */

       if(channel < 0 || channel > 7)
       {
            printf("Channel numbers must be between 0 and 7 - Aborting\n");
            exit(0);
       }

       /* This call sets the mode for the specified channel. We are
          going to set up a singled-ended +/- 10V range. That way any
          legal input can be accomodated.
       */

       gxad_set_channel_mode(channel,GXAD_SINGLE_ENDED,GXAD_BIPOLAR,GXAD_TOP_10V);

	   /* Check to be sure the mode command was accepted OK */

	   if(gxad_error_code)
	   {
		   printf("An error occured - %s\n",gxad_error_string);
		   exit(1);
	   }

       while(1)
       {
            /* We'll keep running until a unrecognized key is pressed */

            if(kbhit())
            {
                c = getch();

                /* The 'C' key clears the min/max and the count */

                if(c == 'c' || c == 'C')
                {
                    count = 0;
                    min = 10.0;
                    max = -10.0;
                }

                /* The 'N' key moves to the next channel, wrapping from
                   7 back to 0 when appropriate.
                */
                
                else if(c == 'n' || c == 'N')
                {
                    printf("\n");
                    channel++;
                    if(channel > 7)
                        channel = 0;

                    /* When we change channels, we need to make sure we set
                       the mode to a valid range.
                    */

                    gxad_set_channel_mode(channel,GXAD_SINGLE_ENDED,GXAD_BIPOLAR,GXAD_TOP_10V);
					if(gxad_error_code)
					{
						printf("An error occured - %s\n",gxad_error_string);
							exit(1);
					}

                    /* A new channel also gets a cleared count and min/max
                       values.
                    */

                    count = 0;
                    min = 10.0;
                    max = -10.0;
                }
                else
                    exit(0);
                
            }

            /* Finally, the real thing. This function call results
               in 2000 conversions on the specified channel with the
               results going into a buffer called "values".
            */

            gxad_convert_single_repeated(channel,2000,values);
			if(gxad_error_code)
			{
				printf("An error occured - %s\n",gxad_error_string);
				exit(1);
			}

            /* Bump up the count */

            count = count + 2000;

            /* Now we'll read out the 2000 conversion values. Convert
               them to floating point voltages and set the min and max
               values as appropriate.
            */

            for(x=0; x<2000; x++)
            {
                result = values[x];

                /* The array gx_adjust linearizes the bipolar modes */

                result = result + gxad_adjust[channel];

                /* The gxad_bitval array holds the value of a single bit
                   in volts. It is multiplied by our conversion value to
                   converto to volts.
                */

                current = result * gxad_bitval[channel];

                /* Bipolar modes must be adjusted once again for
                  a proper +/- voltage range.
                */
                                      
                current = current + gxad_offset[channel];

                /* Check and load min/max as needed */

                if(current < min)
                    min = current;

                if(current > max)
                    max = current;

                /* Print the values */

                printf("CH %1d %09ld %9.5f Min =%9.5f Max =%9.5f\r",channel,count,current,min,max);
             }
       }
}



